@@ -1,6 +1,6 @@
 context("distance_join")
 
-sepal_lengths <- data_frame(Sepal.Length = c(5, 6, 7), Sepal.Width = 1:3, Type = 1:3)
+sepal_lengths <- tibble(Sepal.Length = c(5, 6, 7), Sepal.Width = 1:3, Type = 1:3)
 
 test_that("distance_inner_join works for Euclidean distance", {
   ret <- iris %>%
@@ -86,3 +86,40 @@ test_that("distance_ functions besides inner work", {
   expect_equal(nrow(ret6), sum(is.na(ret2$calculated_distance)))
   expect_equal(colnames(ret6), colnames(iris))
 })
+
+test_that("distance_inner_join works when there's only one distance column", {
+  a <- tibble(x = 1:10)
+  b <- tibble(y = 3:12)
+
+  result <- distance_inner_join(a, b, by = c("x" = "y"), max_dist = 1.5, distance_col = "distance")
+  expect_equal(nrow(result), 24)
+  expect_true(all(result$distance < 1.5))
+})
+
+test_that("distance joins where there are no overlapping rows still get a distance column", {
+  a <- tibble(x = 1:10, y = 1:10)
+  b <- tibble(x = 21:30, y = 21:30)
+
+  result <- distance_left_join(a, b, by = c("x", "y"), max_dist = 1, distance_col = "distance")
+
+  expect_equal(colnames(result), c("x.x", "y.x", "x.y", "y.y", "distance"))
+  expect_equal(nrow(result), 10)
+  expect_true(all(is.na(result$y.y)))
+  expect_true(all(is.na(result$distance)))
+
+  result <- distance_inner_join(a, b, by = c("x", "y"), max_dist = 1, distance_col = "distance")
+
+  expect_equal(colnames(result), c("x.x", "y.x", "x.y", "y.y", "distance"))
+  expect_equal(nrow(result), 0)
+
+  # Don't add it for semi or anti join
+  result <- distance_semi_join(a, b, by = c("x", "y"), max_dist = 1, distance_col = "distance")
+  expect_equal(colnames(result), c("x", "y"))
+  expect_equal(nrow(result), 0)
+
+  result <- distance_anti_join(a, b, by = c("x", "y"), max_dist = 1, distance_col = "distance")
+  expect_equal(colnames(result), c("x", "y"))
+  expect_equal(a, result)
+})
+
+
